import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleBand,
  scaleLinear,
  max,
  format,
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { DropDown } from './DropDown';

const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 80,
  left: 120,
};

const xAxisOffSet = 50;

const attributes = [
    { value: 'Complement', label: 'Complement' }, 
    { value: 'Total Casualties', label: 'Total Casualties' } 
  ];

const App = () => {
  const data = useData();
  console.log(data);
const initialXAttribute = 'Complement';
  const [xAttribute, setXAttribute] = useState(initialXAttribute);
  const xValue = (d) => d[xAttribute];
  //const xAxisLabel = getLabel(xAttribute);
  
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.right - margin.left;

  const yValue = (d) => d.Ship;
	const fateOnDay = d => d['Fate on Day'];

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .paddingInner(0.1);

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  //console.log(xScale.ticks());

  return (
    <>
    <label for="x-select">X</label>
      <DropDown 
      selectedValue={xAttribute}
      options={attributes} 
      id='x-select' 
      onSelectedValueChange={setXAttribute} />
      
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
         
        />
        <AxisLeft yScale={yScale} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisOffSet}
          textAnchor="middle"
        >
          {xAttribute}
        </text>
        <Marks
          data={data}
          yScale={yScale}
          xScale={xScale}
          yValue={yValue}
          xValue={xValue}
          fateOnDay={fateOnDay}
          //tooltipFormat={xAxisTickFormat}
        />
      </g>
    </svg>
      </>
  );
};


const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
